#include "config.h"

#include <stdio.h>
#include <stdlib.h>

#ifdef USE_NLLIBC
#include <nllibc.h>
#endif

#include "const.h"
#include "image.h"
#include "charset.h"

#define CHARACTER_SIZE 32

#define TP 0x80 /* transparent */

#define B_   (1 << 0)
#define B__  (2 << 0)
#define B___ (3 << 0)
#define G_   (1 << 2)
#define G__  (2 << 2)
#define G___ (3 << 2)
#define R_   (1 << 4)
#define R__  (2 << 4)
#define R___ (3 << 4)

#define BK 0x00 /* black */

#define BL (          B___) /* blue */
#define GR (     G___     ) /* green */
#define CY (     G___|B___) /* cyan */
#define RD (R___          ) /* red */
#define MG (R___     |B___) /* magenta */
#define YL (R___|G___     ) /* yellow */
#define WH (R___|G___|B___) /* white */

#define B0 (        B_ )
#define B1 (        B__)
#define G0 (    G_     )
#define G1 (    G__    )
#define C0 (    G_ |B_ )
#define C1 (    G__|B__)
#define R0 (R_         )
#define R1 (R__        )
#define M0 (R_     |B_ )
#define M1 (R__    |B__)
#define Y0 (R_ |G_     )
#define Y1 (R__|G__    )
#define W0 (R_ |G_ |B_ )
#define W1 (R__|G__|B__)

#define C2 (     G_  |B__ )
#define C3 (     G_  |B___)
#define C4 (     G__ |B_  )
#define C5 (     G__ |B___)
#define C6 (     G___|B_  )
#define C7 (     G___|B__ )
#define M2 (R_       |B__ )
#define M3 (R_       |B___)
#define M4 (R__      |B_  )
#define M5 (R__      |B___)
#define M6 (R___     |B_  )
#define M7 (R___     |B__ )
#define Y2 (R_  |G__      )
#define Y3 (R_  |G___     )
#define Y4 (R__ |G_       )
#define Y5 (R__ |G___     )
#define Y6 (R___|G_       )
#define Y7 (R___|G__      )

#define Z0 (R_  |G_  |B__ )
#define Z1 (R_  |G_  |B___)
#define Z2 (R_  |G__ |B_  )
#define Z3 (R_  |G__ |B__ )
#define Z4 (R_  |G__ |B___)
#define Z5 (R_  |G___|B_  )
#define Z6 (R_  |G___|B__ )
#define Z7 (R_  |G___|B___)
#define Z8 (R__ |G_  |B_  )
#define Z9 (R__ |G_  |B__ )
#define ZA (R__ |G_  |B___)
#define ZB (R__ |G__ |B_  )
#define ZC (R__ |G__ |B___)
#define ZD (R__ |G___|B_  )
#define ZE (R__ |G___|B__ )
#define ZF (R__ |G___|B___)
#define ZG (R___|G_  |B_  )
#define ZH (R___|G_  |B__ )
#define ZI (R___|G_  |B___)
#define ZJ (R___|G__ |B_  )
#define ZK (R___|G__ |B__ )
#define ZL (R___|G__ |B___)
#define ZM (R___|G___|B_  )
#define ZN (R___|G___|B__ )

static unsigned char bitmap[] = {
  /* apple */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,G1,G1,G1,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,G1,G1,G1,G1,G1,G1,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,G1,G1,G1,G1,G1,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,TP,TP,TP,TP,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,TP,R0,R0,TP,TP,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,
  TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,
  TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,
  TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,TP,
  TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,WH,RD,RD,TP,
  TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,WH,RD,RD,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* grape */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,R0,M1,M1,TP,M1,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,TP,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M0,M1,M1,M1,M1,M1,M1,M1,M0,M1,M1,M1,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M0,M1,M1,M1,M1,M1,M1,M1,M1,M1,M0,M1,M1,M1,M1,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M0,M1,M1,M1,M1,M1,M0,M0,M1,M1,M1,M0,M1,M1,M1,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,WH,M1,M1,M1,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M1,M1,M0,M1,M1,M0,M0,M1,M1,M1,M1,M1,WH,M1,M1,M1,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M0,M1,M0,M0,M1,M1,M1,M1,M1,M1,M0,M0,M1,M1,M1,M1,M1,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,M0,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,WH,WH,M1,M1,M1,M1,M1,M1,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M1,M0,M1,M1,M1,M1,M1,M0,M1,M1,M0,M1,WH,M1,M1,M1,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M1,M1,M1,M0,M1,M1,M1,M1,M1,M1,M0,M1,M1,M1,M1,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M0,M0,M1,M1,M0,M0,M1,M1,M1,M1,M1,M1,M1,WH,WH,M1,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M0,M1,M1,M0,M1,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M0,M1,M1,M1,M1,M1,M1,M1,M1,M1,M0,M1,M1,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,WH,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M1,M1,M0,WH,WH,M1,M1,WH,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M1,M1,M1,M1,M1,WH,M1,M0,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M0,M1,M1,WH,M1,WH,M1,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,M1,M0,M0,M1,M1,M1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,WH,WH,M0,M1,M1,M1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,M1,WH,M1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,M1,M1,M1,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* watermelon */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,BK,GR,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,GR,
  TP,TP,TP,G0,GR,WH,RD,RD,RD,RD,RD,RD,RD,BK,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,GR,
  TP,TP,TP,G0,GR,WH,RD,ZM,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,R1,RD,RD,RD,RD,RD,RD,RD,RD,GR,
  TP,TP,TP,BK,GR,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,BK,RD,RD,RD,RD,RD,RD,WH,GR,
  TP,TP,TP,G0,GR,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,GR,
  TP,TP,TP,G0,GR,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,GR,GR,
  TP,TP,TP,TP,GR,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,GR,G0,
  TP,TP,TP,TP,BK,GR,RD,RD,RD,ZM,RD,RD,RD,RD,RD,RD,RD,R1,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,GR,BK,
  TP,TP,TP,TP,G0,GR,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,GR,GR,BK,
  TP,TP,TP,TP,G0,G0,GR,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,GR,GR,G0,G0,
  TP,TP,TP,TP,G0,G0,GR,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,BK,RD,RD,RD,RD,RD,RD,RD,WH,GR,GR,G0,TP,
  TP,TP,TP,TP,TP,G0,BK,GR,WH,RD,RD,RD,ZM,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,GR,GR,G0,G0,TP,
  TP,TP,TP,TP,TP,TP,G0,G0,GR,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,BK,RD,WH,GR,GR,BK,BK,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,G0,BK,GR,GR,WH,WH,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,RD,WH,GR,GR,G0,BK,BK,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,G0,G0,G0,GR,GR,GR,WH,WH,WH,WH,WH,WH,WH,WH,WH,WH,GR,GR,G0,G0,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,G0,G0,BK,G0,G0,BK,G0,G0,GR,WH,G0,GR,GR,GR,G0,BK,G0,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,BK,G0,G0,BK,G0,G0,G0,BK,G0,G0,BK,G0,G0,BK,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* peach */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,TP,
  TP,TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,
  TP,TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,TP,
  TP,TP,TP,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,TP,
  TP,TP,TP,ZN,ZN,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,
  TP,TP,TP,ZN,ZN,ZN,ZN,ZK,ZK,ZN,ZK,ZK,ZN,ZN,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZK,ZN,TP,
  TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZK,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C6,
  TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C6,
  TP,TP,TP,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C6,C6,
  TP,TP,C6,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C6,C6,C6,
  TP,TP,C6,C6,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C6,C6,C6,C6,
  TP,C6,C6,C6,C6,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C6,C6,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,ZN,C6,C6,C6,C6,C6,C6,
  TP,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,TP,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,
  C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,TP,TP,TP,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,
  TP,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,TP,TP,TP,TP,TP,TP,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,
  TP,TP,C6,C6,C6,C6,C6,C6,C6,C6,TP,TP,TP,TP,TP,TP,TP,TP,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,
  TP,TP,TP,TP,C6,C6,C6,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,C6,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,C6,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,

  /* banana */
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,R0,R0,R0,R0,R0,R0,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,R0,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,
  TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,
  TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,
  TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,
  TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,
  TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,
  YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,
  TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,
  TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,
  TP,TP,YL,YL,YL,YL,YL,TP,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,YL,YL,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,YL,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,YL,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
  TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,TP,
};

struct charset charset_character_2 = {
  CHARACTER_SIZE, CHARACTER_SIZE,
  sizeof(bitmap) / (sizeof(*bitmap) * CHARACTER_SIZE * CHARACTER_SIZE),
  { NULL, bitmap },
  IMAGE_TYPE_ROUGHCOLOR, NLL_G_STATIC
};
